@@ -14,11 +14,22 @@ class FilernameCdAdmin(BaseAdmin):
         "status",
         "effect_dt",
     )
-    list_filter = ("filer_type",)
+    list_filter = ("filer_type", "status")
+    search_fields = (
+        "xref_filer_id",
+        "filer_id",
+        "naml",
+        "namf",
+    )
+    date_hierarchy = "effect_dt"
 
 
 class FilerFilingsCdAdmin(BaseAdmin):
-    pass
+    search_fields = ("filing_id", "filer_id")
+    list_display = (
+        "id", "filer_id", "form_id",
+        "filing_id", "filing_sequence"
+    )
 
 
 class FilingsCdAdmin(BaseAdmin):
