@@ -5,25 +5,29 @@ from .base import CalAccessBaseModel
 
 class AcronymsCd(CalAccessBaseModel):
     DATE_FIELDS = ("EFFECT_DT",)
-    acronym = models.CharField(max_length=25, db_column="ACRONYM")
+    acronym = models.CharField(max_length=40, db_column="ACRONYM")
     stands_for = models.CharField(max_length=4, db_column="STANDS_FOR")
     effect_dt = models.DateField(db_column="EFFECT_DT")
-    a_desc = models.CharField(max_length=25, db_column="A_DESC")
+    a_desc = models.CharField(max_length=50, db_column="A_DESC")
 
     class Meta:
         app_label = 'calaccess_raw'
         db_table = 'ACRONYMS_CD'
         verbose_name = 'ACRONYMS_CD'
         verbose_name_plural = 'ACRONYMS_CD'
+        ordering = ("acronym",)
+
+    def __unicode__(self):
+        return self.acronym
 
 
 class AddressCd(CalAccessBaseModel):
     adrid = models.IntegerField(db_column="ADRID")
     city = models.CharField(max_length=500, db_column="CITY")
     st = models.CharField(max_length=500, db_column="ST")
-    zip4 = models.IntegerField(db_column="ZIP4")
-    phon = models.IntegerField(db_column="PHON")
-    fax = models.IntegerField(db_column="FAX")
+    zip4 = models.CharField(db_column="ZIP4", null=True, max_length=10L)
+    phon = models.CharField(db_column="PHON", null=True, max_length=20L)
+    fax = models.CharField(db_column="FAX", null=True, max_length=20L)
     email = models.CharField(max_length=500, db_column="EMAIL")
 
     class Meta:
@@ -80,8 +84,8 @@ class FilersCd(CalAccessBaseModel):
 
 
 class FilerAcronymsCd(CalAccessBaseModel):
-    acronym = models.CharField(max_length=32L)
-    filer_id = models.IntegerField()
+    acronym = models.CharField(db_column='ACRONYM', max_length=32L)
+    filer_id = models.IntegerField(db_column='FILER_ID')
 
     class Meta:
         app_label = 'calaccess_raw'
@@ -169,14 +173,24 @@ class FilerLinksCd(CalAccessBaseModel):
 
 
 class FilerStatusTypesCd(CalAccessBaseModel):
-    status_type = models.CharField(max_length=11L, db_column='STATUS_TYPE')
-    status_desc = models.CharField(max_length=11L, db_column='STATUS_DESC')
+    status_type = models.CharField(
+        max_length=11L,
+        db_column='STATUS_TYPE',
+    )
+    status_desc = models.CharField(
+        max_length=11L,
+        db_column='STATUS_DESC'
+    )
 
     class Meta:
         app_label = 'calaccess_raw'
         db_table = 'FILER_STATUS_TYPES_CD'
         verbose_name = 'FILER_STATUS_TYPES_CD'
         verbose_name_plural = 'FILER_STATUS_TYPES_CD'
+        ordering = ("status_type",)
+
+    def __unicode__(self):
+        return self.status_type
 
 
 class FilerToFilerTypeCd(CalAccessBaseModel):
@@ -184,39 +198,98 @@ class FilerToFilerTypeCd(CalAccessBaseModel):
         'EFFECT_DT',
         'NYQ_DT'
     )
-    filer_id = models.IntegerField(db_column='FILER_ID')
-    filer_type = models.IntegerField(db_column='FILER_TYPE')
-    active = models.CharField(max_length=1L, db_column='ACTIVE')
-    race = models.IntegerField(null=True, db_column='RACE', blank=True)
-    session_id = models.IntegerField(db_column='SESSION_ID')
+    filer_id = models.IntegerField(
+        db_column='FILER_ID',
+        help_text="Filer's unique identification number"
+    )
+    filer_type = models.IntegerField(
+        db_column='FILER_TYPE',
+        help_text="Filer type identification number"
+    )
+    active = models.CharField(
+        max_length=1L,
+        db_column='ACTIVE',
+        help_text="Indicates if the filer is currently active"
+    )
+    race = models.IntegerField(
+        null=True,
+        db_column='RACE',
+        blank=True,
+        help_text="If applicable indicates the race in which the filer is \
+running"
+    )
+    session_id = models.IntegerField(
+        db_column='SESSION_ID',
+        help_text="Legislative session identification number"
+    )
     category = models.IntegerField(
-        null=True, db_column='CATEGORY', blank=True
+        null=True,
+        db_column='CATEGORY',
+        blank=True,
+        help_text="Defines the filer's category such as controlled, jointly \
+controlled, etc. (subset of filer's type)"
     )
     category_type = models.IntegerField(
-        null=True, db_column='CATEGORY_TYPE', blank=True
+        null=True,
+        db_column='CATEGORY_TYPE',
+        blank=True,
+        help_text="When applicable, the category type specifies additional \
+information about the category. (e.g. state, local, etc.)"
     )
     sub_category = models.IntegerField(
-        null=True, db_column='SUB_CATEGORY', blank=True
+        null=True,
+        db_column='SUB_CATEGORY',
+        blank=True,
+        help_text="When applicable specifies general purpose, primarily \
+formed, etc."
+    )
+    effect_dt = models.DateField(
+        db_column='EFFECT_DT',
+        help_text="The date the filer assumed the current class or type"
     )
-    effect_dt = models.DateField(db_column='EFFECT_DT')
     sub_category_type = models.IntegerField(
-        null=True, db_column='SUB_CATEGORY_TYPE', blank=True
+        null=True,
+        db_column='SUB_CATEGORY_TYPE',
+        blank=True,
+        help_text="When applicable specifies broad based or small contributor"
     )
     election_type = models.IntegerField(
-        null=True, db_column='ELECTION_TYPE', blank=True
+        null=True,
+        db_column='ELECTION_TYPE',
+        blank=True,
+        help_text="Indicates type of election (general, primary, special)"
     )
     sub_category_a = models.CharField(
-        max_length=1L, db_column='SUB_CATEGORY_A', blank=True
+        max_length=1L,
+        db_column='SUB_CATEGORY_A',
+        blank=True,
+        help_text="Indicates if sponsored or not"
+    )
+    nyq_dt = models.DateField(
+        null=True,
+        db_column='NYQ_DT',
+        blank=True,
+        help_text="Indicates the date when a committee reached its qualifying \
+level of activity"
     )
-    nyq_dt = models.DateField(null=True, db_column='NYQ_DT', blank=True)
     party_cd = models.IntegerField(
-        null=True, db_column='PARTY_CD', blank=True
+        null=True,
+        db_column='PARTY_CD',
+        blank=True,
+        help_text="Filer's political party"
     )
     county_cd = models.IntegerField(
-        null=True, db_column='COUNTY_CD', blank=True
+        null=True,
+        db_column='COUNTY_CD',
+        blank=True,
+        help_text="Filer's county code"
     )
     district_cd = models.IntegerField(
-        null=True, db_column='DISTRICT_CD', blank=True
+        null=True,
+        db_column='DISTRICT_CD',
+        blank=True,
+        help_text="Filer's district number for the office being sought. \
+Populated for Senate, Assembly or Board of Equalization races"
     )
 
     class Meta:
@@ -225,16 +298,34 @@ class FilerToFilerTypeCd(CalAccessBaseModel):
         verbose_name = 'FILER_TO_FILER_TYPE_CD'
         verbose_name_plural = 'FILER_TO_FILER_TYPE_CD'
 
+    def __unicode__(self):
+        return unicode(self.filer_id)
+
 
 class FilerTypesCd(CalAccessBaseModel):
-    filer_type = models.IntegerField(db_column='FILER_TYPE')
-    description = models.CharField(max_length=255L, db_column='DESCRIPTION')
-    grp_type = models.IntegerField(null=True, db_column='GRP_TYPE', blank=True)
+    filer_type = models.IntegerField(
+        db_column='FILER_TYPE',
+        help_text="Filer type identification number"
+    )
+    description = models.CharField(
+        max_length=255,
+        db_column='DESCRIPTION',
+        help_text="Description of the filer type"
+    )
+    grp_type = models.IntegerField(
+        null=True,
+        db_column='GRP_TYPE',
+        blank=True,
+        help_text="Group type assocated with the filer type"
+    )
     calc_use = models.CharField(
-        max_length=1L, db_column='CALC_USE', blank=True
+        max_length=1,
+        db_column='CALC_USE',
+        blank=True,
+        help_text="Use checkbox flag"
     )
     grace_period = models.CharField(
-        max_length=12L, db_column='GRACE_PERIOD', blank=True
+        max_length=12, db_column='GRACE_PERIOD', blank=True
     )
 
     class Meta:
@@ -242,6 +333,10 @@ class FilerTypesCd(CalAccessBaseModel):
         db_table = 'FILER_TYPES_CD'
         verbose_name = 'FILER_TYPES_CD'
         verbose_name_plural = 'FILER_TYPES_CD'
+        ordering = ("filer_type",)
+
+    def __unicode__(self):
+        return unicode(self.filer_type)
 
 
 class FilerXrefCd(CalAccessBaseModel):
@@ -263,24 +358,46 @@ class FilerXrefCd(CalAccessBaseModel):
 
 
 class FilingPeriodCd(CalAccessBaseModel):
-    DATE_FIELDS = [
+    DATE_FIELDS = (
         'START_DATE',
         'END_DATE',
         'DEADLINE'
-    ]
-    period_id = models.IntegerField(db_column='PERIOD_ID')
-    start_date = models.DateField(db_column='START_DATE')
-    end_date = models.DateField(db_column='END_DATE')
-    period_type = models.IntegerField(db_column='PERIOD_TYPE')
-    per_grp_type = models.IntegerField(db_column='PER_GRP_TYPE')
-    period_desc = models.CharField(max_length=255L, db_column='PERIOD_DESC')
-    deadline = models.DateField(db_column='DEADLINE')
+    )
+    period_id = models.IntegerField(
+        db_column='PERIOD_ID',
+        help_text="Unique period identification number"
+    )
+    start_date = models.DateField(
+        db_column='START_DATE',
+        help_text="Starting date for period"
+    )
+    end_date = models.DateField(
+        db_column='END_DATE',
+        help_text="Ending date of period"
+    )
+    period_type = models.IntegerField(
+        db_column='PERIOD_TYPE',
+    )
+    per_grp_type = models.IntegerField(
+        db_column='PER_GRP_TYPE',
+        help_text="Period group type"
+    )
+    period_desc = models.CharField(
+        max_length=255,
+        db_column='PERIOD_DESC',
+        help_text="Period description"
+    )
+    deadline = models.DateField(
+        db_column='DEADLINE',
+        help_text="Deadline date"
+    )
 
     class Meta:
         app_label = 'calaccess_raw'
         db_table = 'FILING_PERIOD_CD'
         verbose_name = 'FILING_PERIOD_CD'
         verbose_name_plural = 'FILING_PERIOD_CD'
+        ordering = ("-end_date",)
 
 
 class GroupTypesCd(CalAccessBaseModel):
@@ -332,19 +449,29 @@ class HdrCd(CalAccessBaseModel):
     ef_type = models.CharField(max_length=3L, db_column='EF_TYPE', blank=True)
     filing_id = models.IntegerField(db_column='FILING_ID')
     hdr_comment = models.CharField(
-        max_length=200L, db_column='HDRCOMMENT', blank=True
+        max_length=200L,
+        db_column='HDRCOMMENT',
+        blank=True
     )
     rec_type = models.CharField(
-        max_length=3L, db_column='REC_TYPE', blank=True
+        max_length=3L,
+        db_column='REC_TYPE',
+        blank=True
     )
     soft_name = models.CharField(
-        max_length=90L, db_column='SOFT_NAME', blank=True
+        max_length=90L,
+        db_column='SOFT_NAME',
+        blank=True
     )
     soft_ver = models.CharField(
-        max_length=16L, db_column='SOFT_VER', blank=True
+        max_length=16L,
+        db_column='SOFT_VER',
+        blank=True
     )
     state_cd = models.CharField(
-        max_length=2L, db_column='STATE_CD', blank=True
+        max_length=2L,
+        db_column='STATE_CD',
+        blank=True
     )
 
     class Meta:
@@ -395,7 +522,7 @@ class LobbyingChgLogCd(CalAccessBaseModel):
     )
     filer_id = models.IntegerField(db_column='FILER_ID')
     change_no = models.IntegerField(db_column='CHANGE_NO')
-    session_id = models.IntegerField(db_column='SESSION_ID')
+    session_id = models.IntegerField(db_column='SESSION_ID', null=True)
     log_dt = models.DateField(db_column="LOG_DT")
     filer_type = models.IntegerField(db_column='FILER_TYPE')
     correction_flag = models.CharField(
@@ -415,15 +542,21 @@ class LobbyingChgLogCd(CalAccessBaseModel):
     )
     filer_city = models.CharField(max_length=200, db_column="FILER_CITY")
     filer_st = models.CharField(max_length=200, db_column="FILER_ST")
-    filer_zip = models.IntegerField(db_column="FILER_ZIP")
-    filer_phone = models.IntegerField(db_column="FILER_PHONE")
-    entity_type = models.IntegerField(db_column="ENTITY_TYPE")
+    filer_zip = models.IntegerField(db_column="FILER_ZIP", null=True)
+    filer_phone = models.CharField(
+        db_column="FILER_PHONE", null=True, max_length=12L
+    )
+    entity_type = models.IntegerField(db_column="ENTITY_TYPE", null=True)
     entity_name = models.CharField(max_length=500, db_column="ENTITY_NAME")
     entity_city = models.CharField(max_length=500, db_column="ENTITY_CITY")
     entity_st = models.CharField(max_length=500, db_column="ENTITY_ST")
-    entity_zip = models.IntegerField(db_column="ENTITY_ZIP")
-    entity_phone = models.IntegerField(db_column="ENTITY_PHONE")
-    entity_id = models.IntegerField(db_column="ENTITY_ID")
+    entity_zip = models.CharField(
+        db_column="ENTITY_ZIP", blank=True, max_length=10L
+    )
+    entity_phone = models.CharField(
+        db_column="ENTITY_PHONE", null=True, max_length=12L
+    )
+    entity_id = models.IntegerField(db_column="ENTITY_ID", null=True)
     responsible_officer = models.CharField(
         max_length=500, db_column="RESPONSIBLE_OFFICER"
     )
@@ -881,9 +1014,9 @@ class LobbyistFirmLobbyist2Cd(CalAccessBaseModel):
 
 
 class LookupCode(CalAccessBaseModel):
-    code_type = models.IntegerField()
-    code_id = models.IntegerField()
-    code_desc = models.CharField(max_length=100)
+    code_type = models.IntegerField(db_column='CODE_TYPE')
+    code_id = models.IntegerField(db_column='CODE_ID')
+    code_desc = models.CharField(max_length=100, null=True)
 
     class Meta:
         app_label = 'calaccess_raw'
